package com.ruoyi.system.service;

import java.time.LocalDate;
import java.util.List;
import com.ruoyi.system.domain.SysOrder;
import com.ruoyi.system.domain.dto.OrderDetailDto;
import com.ruoyi.system.domain.dto.OrderListDto;
import com.ruoyi.system.domain.dto.SysOrderPayBackDto;

/**
 * 订单信息Service接口
 * 
 * @author haotian
 * @date 2024-11-21
 */
public interface ISysOrderService 
{
    /**
     * 查询订单信息
     * 
     * @param orderId 订单信息主键
     * @return 订单信息
     */
    public SysOrder selectSysOrderByOrderId(Long orderId);

    /**
     * 查询订单信息列表
     * 
     * @param sysOrder 订单信息
     * @return 订单信息集合
     */
    public List<SysOrder> selectSysOrderList(SysOrder sysOrder);

    /**
     * 新增订单信息
     * 
     * @param sysOrder 订单信息
     * @return 结果
     */
    public int insertSysOrder(SysOrder sysOrder);

    /**
     * 修改订单信息
     * 
     * @param sysOrder 订单信息
     * @return 结果
     */
    public int updateSysOrder(SysOrder sysOrder);

    /**
     * 批量删除订单信息
     * 
     * @param orderIds 需要删除的订单信息主键集合
     * @return 结果
     */
    public int deleteSysOrderByOrderIds(Long[] orderIds);

    /**
     * 删除订单信息信息
     * 
     * @param orderId 订单信息主键
     * @return 结果
     */
    public int deleteSysOrderByOrderId(Long orderId);


    /*
    * 查询订单是否合法
    * */
    public int isTimeLegal(LocalDate startTime, LocalDate endTime, Long sourceId);

    /*
    * 营销管理获取订单列表
    * */

    public List<OrderListDto> getOrderListDto(SysOrder sysOrder);

    /*
    * 营销管理--获取订单的详细信息
    * */
    public OrderDetailDto getOrderDetailDto(Long orderId, Long id);

    /*
    * 系统每天--根据日期 计数收入
    * */
    public Long getMoneybyDateAndStatus(LocalDate date);

    /*
    * 系统每天--根据日期计数退款
    * */
    public Long getRefund(LocalDate date);

    /**
     *
     * 支付回调后根据orderId返回订单详情
     * */
    public SysOrderPayBackDto getSysOrderPayBackDto(Long orderId);
}
